@@ -18,24 +18,24 @@ test_that("gradients are correct", {
 
   x <- structure(1:3, names = c("A", "B", "C"))
   g <- Grad(f, x, h = 0.01)
-  expect_equal(attr(g, "step.size.method"), "user-supplied")
-  expect_equal(names(g), c("A", "B", "C"))
+  expect_identical(attr(g, "step.size.method"), "user-supplied")
+  expect_named(g, c("A", "B", "C"))
 })
 
 test_that("Gradient step is auto-selected well", {
   f <- function(x) sum(sin(x))
-  expect_equal(attr(Grad(x = 1:3, f), "step.size.method"), "default")
-  expect_equal(attr(Grad(x = 1:3, f, h = 0.01), "step.size.method"), "user-supplied")
-  expect_equal(attr(Grad(x = 1:3, f, h = "CR"), "step.size.method"), "CR")
-  expect_equal(attr(Grad(x = 1:3, f, h = "SW"), "step.size.method"), "SW")
+  expect_identical(attr(Grad(x = 1:3, f), "step.size.method"), "default")
+  expect_identical(attr(Grad(x = 1:3, f, h = 0.01), "step.size.method"), "user-supplied")
+  expect_identical(attr(Grad(x = 1:3, f, h = "CR"), "step.size.method"), "CR")
+  expect_identical(attr(Grad(x = 1:3, f, h = "SW"), "step.size.method"), "SW")
   g <- Grad(x = 1:3, FUN = f, h = "SW", elementwise = FALSE,
             vectorised = FALSE, multivalued = FALSE)
-  expect_equal(attr(g, "step.search")[["exitcode"]], rep(0, 3), tolerance = 1e-15)
-  expect_length(attr(g, "step.search")[["iterations"]], 3)
+  expect_equal(attr(g, "step.search")[["exitcode"]], rep(0L, 3), tolerance = 1e-15)
+  expect_length(attr(g, "step.search")[["original"]], 3)
 })
 
 test_that("parallelisation of Grad works", {
-  expect_equal(Grad(x = 1:3, FUN = sum, cores = 1),
+  expect_identical(Grad(x = 1:3, FUN = sum, cores = 1),
                Grad(x = 1:3, FUN = sum, cores = 2))
 })
 
@@ -54,8 +54,8 @@ test_that("Grad can accept dot arguments", {
   # These dot arguments must be accepted and used by checkDimensions()
   # and gradstep()
   f <- function(x, a0) sin(x + a0)
-  expect_equal(Grad(f, x = 0, a0 = 1, h = 1e-5), Grad(sin, x = 1, h = 1e-5))
-  expect_equal(attr(Grad(f, x = 0, a0 = 1, h = "SW"), "step.search")$exitcode, 0)
+  expect_identical(Grad(f, x = 0, a0 = 1, h = 1e-5), Grad(sin, x = 1, h = 1e-5))
+  expect_identical(attr(Grad(f, x = 0, a0 = 1, h = "SW"), "step.search")$exitcode, 0L)
 })
 
 test_that("Grad can work on an arbitrary stencil", {
