@@ -10,18 +10,18 @@ test_that("Stepleman--Winarsky step selection handles inputs well", {
 test_that("Stepleman--Winarsky step selection behaves reasonably", {
   f <- function(x) x^4
   s <- step.SW(x = 2, f)
-  expect_equal(s$exitcode, 0)
+  expect_identical(s$exitcode, 0L)
   expect_lt(sum(s$abs.error), 1e-6)
   expect_equal(s$value, 32, tolerance = 1e-8)
   monot <- s$iterations$monotone[sum(s$counts), ]
   # Stopping criterion
-  expect_true(any(!monot))
+  expect_false(all(monot))
 })
 
 test_that("SW algorithm detects if h0 is too low", {
   f <- function(x) x^4
   s <- step.SW(x = 2, f, h0 = 1e-9)
-  expect_equal(s$exitcode, 0)
+  expect_identical(s$exitcode, 0L)
   expect_lt(s$iterations$h[1], s$iterations$h[2])
   expect_equal(s$value, 32, tolerance = 1e-8)
 })
@@ -29,7 +29,7 @@ test_that("SW algorithm detects if h0 is too low", {
 test_that("SW algorithm takes longer if h0 is too high", {
   f <- function(x) x^4
   s <- step.SW(x = pi/2, f, h0 = 10)
-  expect_equal(s$exitcode, 0)
+  expect_identical(s$exitcode, 0L)
   expect_gt(s$counts["preliminary"], 3)
 
   s2 <- step.SW(x = pi/2, f, h0 = 1e4)
@@ -38,8 +38,8 @@ test_that("SW algorithm takes longer if h0 is too high", {
 
 test_that("SW algorithm for bad ranges", {
   f <- function(x) x^4
-  expect_equal(step.SW(x = 2, f, h0 = 0.1, range = c(0.01, 1))$exitcode, 3)
-  expect_equal(suppressWarnings(step.SW(x = 2, f, h0 = 1e-9, range = c(1e-10, 1e-8)))$exitcode, 3)
+  expect_identical(step.SW(x = 2, f, h0 = 0.1, range = c(0.01, 1))$exitcode, 3L)
+  expect_identical(suppressWarnings(step.SW(x = 2, f, h0 = 1e-9, range = c(1e-10, 1e-8)))$exitcode, 3L)
 })
 
 test_that("SW algorithm stops if the function returns NA for all allowed step sizes", {
@@ -49,13 +49,12 @@ test_that("SW algorithm stops if the function returns NA for all allowed step si
 
 
 test_that("SW fails when a large h0 invalidates the est. trunc. error", {
-  expect_warning(step.SW(x = pi/4, FUN = sin, h0 = 1000),
-                 "exceeds 1% of |x|")
+  expect_identical(step.SW(x = pi/4, FUN = sin, h0 = 1000)$exitcode, 4L)
 })
 
 test_that("Parallelisation in SW works", {
-  expect_equal(step.SW(sin, 1, cores = 1), step.SW(sin, 1, cores = 2))
+  expect_identical(step.SW(sin, 1, cores = 1), step.SW(sin, 1, cores = 2))
   clus <- parallel::makePSOCKcluster(2)
-  expect_equal(step.SW(sin, 1, cores = 1), step.SW(sin, 1, cl = clus))
+  expect_identical(step.SW(sin, 1, cores = 1), step.SW(sin, 1, cl = clus))
   parallel::stopCluster(clus)
 })
