@@ -3,13 +3,13 @@ test_that("Plug-in step handles inputs well", {
 })
 
 test_that("Plug-in step checks for small truncation errors", {
-  expect_equal(step.plugin(sin, pi/3)$exitcode, 0)
-  expect_equal(step.plugin(function(x) x, pi/2)$exitcode, 1)
+  expect_identical(step.plugin(sin, pi/3)$exitcode, 0L)
+  expect_identical(step.plugin(function(x) x, pi/2)$exitcode, 1L)
 })
 
 test_that("Plug-in step checks for resprecting the ranges", {
-  expect_equal(step.plugin(sin, pi/3, range = c(1e-4, 1e-3))$exitcode, 3)
-  expect_equal(step.plugin(sin, pi/3, range = c(1e-9, 1e-8))$exitcode, 3)
+  expect_identical(step.plugin(sin, pi/3, range = c(1e-4, 1e-3))$exitcode, 3L)
+  expect_identical(step.plugin(sin, pi/3, range = c(1e-9, 1e-8))$exitcode, 3L)
 })
 
 test_that("Plug-in algorithm stops if the function returns NA for all allowed step sizes", {
@@ -18,12 +18,12 @@ test_that("Plug-in algorithm stops if the function returns NA for all allowed st
 })
 
 test_that("Parallelisation in plug-in step selection works", {
-  expect_equal(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cores = 2))
+  expect_identical(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cores = 2))
 })
 
 test_that("User request in plug-in step selection for fewer cores is honoured", {
-  expect_equal(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cores = 2))
+  expect_identical(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cores = 2))
   clus <- parallel::makePSOCKcluster(2)
-  expect_equal(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cl = clus))
+  expect_identical(step.plugin(sin, 1, cores = 1), step.plugin(sin, 1, cl = clus))
   parallel::stopCluster(clus)
 })
